@@ -1,14 +1,12 @@
 """
 Pillar module is responsible for handling the whole execution chain including
-managing a lock file, executing the registered laws, pushing the changes to
-the VCS and creating a pull request. All the laws registered to the pillar
-will be executed in the order of the registration.
+executing the registered laws, pushing the changes to the VCS and creating a
+pull request. All the laws registered to the pillar will be executed in the
+order of the registration.
 """
 
 
 from datetime import datetime
-import logging
-from pathlib import Path
 from typing import List, Type
 
 from hammurabi.law import Law
@@ -21,8 +19,6 @@ from hammurabi.rules.base import Rule
 class Pillar(GitHubMixin):
     """
     Pillar is responsible for the execution of the chain of laws and rules.
-    During the execution process a lock file will be created at the beginning
-    of the process and at the end, the lock file will be released.
 
     All the registered laws and rules can be retrieved using the ``laws`` and
     ``rules`` properties, or if necessary single laws and rules can be accessed
@@ -39,7 +35,6 @@ class Pillar(GitHubMixin):
 
     def __init__(self, reporter_class: Type[Reporter] = JSONReporter) -> None:
         self.__laws: List[Law] = list()
-        self.__lock_file = Path("hammurabi.lock")
 
         self.reporter: Reporter = reporter_class(list())
 
@@ -59,27 +54,6 @@ class Pillar(GitHubMixin):
 
         return [rule for law in self.laws for rule in law.rules]
 
-    def create_lock_file(self):
-        """
-        Create a lock file. If the lock file presents, the execution for
-        the same target will be prevented.
-        """
-
-        if self.__lock_file.exists():
-            raise RuntimeError(f"{self.__lock_file} already exists")
-
-        logging.debug("Creating lock file")
-        self.__lock_file.touch()
-
-    def release_lock_file(self):
-        """
-        Releasing the previously created lock file if exists.
-        """
-
-        if self.__lock_file.exists():
-            logging.debug("Releasing lock file")
-            self.__lock_file.unlink()
-
     def get_law(self, name: str) -> Law:
         """
         Get a law by its name. In case of no Laws are registered or
@@ -156,8 +130,8 @@ class Pillar(GitHubMixin):
     def enforce(self):
         """
         Run all the registered laws and rules one by one. This method is responsible
-        for creating and releasing the lock file, executing the registered laws, push
-        changes to the git origin and open the pull request.
+        for executing the registered laws, push changes to the git origin and open
+        the pull request.
 
         This method glues together the lower level components and makes sure that the
         execution of laws and rules can not be called more than once at the same time
@@ -165,14 +139,10 @@ class Pillar(GitHubMixin):
         """
 
         self.reporter.additional_data.started = datetime.now().isoformat()
-        self.create_lock_file()
         self.checkout_branch()
 
-        try:
-            for law in self.laws:
-                law.enforce()
-        finally:
-            self.release_lock_file()
+        for law in self.laws:
+            law.enforce()
 
         self.push_changes()
         pull_request_url = self.create_pull_request()
